AppleVisionDocumentScannerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- AppleVisionDocumentScannerPlatform
- Implementers
Constructors
- AppleVisionDocumentScannerPlatform()
- Constructs a AppleVisionDocumentScannerPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
destroy(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scan(
) → Future< List< File> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AppleVisionDocumentScannerPlatform
-
The default instance of AppleVisionDocumentScannerPlatform to use.
getter/setter pair